#!/bin/bash
# Wrapper to call kiwi-ng
# Check that we're root.
if test "$UID" != "0"; then exec sudo $0 "$@"; fi
# Set source dir
THISDIR=`dirname "$0"`
if test "${THISDIR:0:1}" == "."; then THISDIR=`pwd`/$THISDIR; fi
# Set target dir and clean
TARGETDIR=/ImgData/tmp/kiwi-otc155-JeOS/
# Find name
CONFIG="$THISDIR/config.xml"
NAME=$(grep '<image' $CONFIG | sed "s/^.* name=['\"]\([^'\"]*\)['\"].*$/\1/")
VERSION=$(grep '<version>' $CONFIG | sed "s/^[^<]*<version>\([^<]*\).*$/\1/")
IMGFMT=$(grep '<type.*vmx.*format' $CONFIG | sed "s/^ *<type.*format=[\"']\([^\"']*\).*$/\1/")
if test -z "$IMGFMT"; then IMGFMT=raw; fi
ARCH=$(uname -m)
ONM=$NAME.$ARCH-$VERSION
if test -e "$TARGETDIR/$ONM.$IMGFMT"; then
  echo -n "File $TARGETDIR/$ONM.$IMGFMT exists, overwrite? "
  read ans
  if test "$ans" != "y" -a "$ans" != "Y"; then exit 1; fi
fi
# Clean target dir
rm -rf $TARGETDIR/build/image-root
# Call kiwi
echo "kiwi-ng --type=vmx  --color-output system build  --description=\"$THISDIR\" --target-dir=\"$TARGETDIR\" --signing-key=keys/gpg-pubkey-05a6c49c-633ec846.asc --signing-key=keys/gpg-pubkey-25db7ae0-645bae34.asc --signing-key=keys/gpg-pubkey-29b700a4-62b07e22.asc --signing-key=keys/gpg-pubkey-39db7c82-5f68629b.asc --signing-key=keys/gpg-pubkey-3dbdc284-53674dd4.asc --signing-key=keys/gpg-pubkey-65176565-61a0ee8f.asc --signing-key=keys/gpg-pubkey-69db3dc5-6548c05d.asc --signing-key=keys/gpg-pubkey-d85f9316-639fcc58.asc --signing-key=keys/gpg-pubkey-e6e5a213-65704093.asc --signing-key=keys/gpg-pubkey-edf0d733-64c6ae0d.asc"
kiwi-ng --type=vmx  --color-output system build  --description="$THISDIR" --target-dir="$TARGETDIR" --signing-key=keys/gpg-pubkey-05a6c49c-633ec846.asc --signing-key=keys/gpg-pubkey-25db7ae0-645bae34.asc --signing-key=keys/gpg-pubkey-29b700a4-62b07e22.asc --signing-key=keys/gpg-pubkey-39db7c82-5f68629b.asc --signing-key=keys/gpg-pubkey-3dbdc284-53674dd4.asc --signing-key=keys/gpg-pubkey-65176565-61a0ee8f.asc --signing-key=keys/gpg-pubkey-69db3dc5-6548c05d.asc --signing-key=keys/gpg-pubkey-d85f9316-639fcc58.asc --signing-key=keys/gpg-pubkey-e6e5a213-65704093.asc --signing-key=keys/gpg-pubkey-edf0d733-64c6ae0d.asc
RC=$?
if test $RC = 0 -a -e "$TARGETDIR/$ONM.$IMGFMT"; then
  echo "Build successful."
  if test $IMGFMT = "raw"; then
    echo "Cleaning $ONM.raw  ..."
    zerofree $TARGETDIR/$ONM.raw
    echo "Convert $ONM.raw to $ONM.qcow2 ..."
    qemu-img convert -c -O qcow2 $TARGETDIR/$ONM.raw $TARGETDIR/$ONM.qcow2
    IMGFMT=qcow2
  fi
  if test -e "$TARGETDIR/$ONM.raw"; then rm $TARGETDIR/$ONM.raw; fi
  echo "Clean up $TARGETDIR/build/image-root ..."
  rm -rf $TARGETDIR/build/image-root
fi
exit $RC
